Gammapy examples folder
=======================

This folder contains the following:

* Python scripts tutorials that may be downloaded with ``gammapy download scripts`` command.
* Python scripts needed by the sphinx-gallery extension to produce collections of examples use cases.

Only the Python scripts declared in the ``scripts.yaml`` file are downloaded by the
``gammapy download scripts`` command. This list is versioned for each release of Gammapy
as it is also the case for the Jupyter notebooks tutorials placed in the tutorials
folder.

The Python scripts needed by sphinx-gallery extension are placed in folders declared in
the ``sphinx_gallery_conf`` variable in ``docs/conf.py`` script.

See info at: https://docs.gammapy.org/
